@@ -19,6 +19,7 @@
 #ifndef APIUTIL_H_INCLUDED
 #define APIUTIL_H_INCLUDED
 
+#include <array>
 #include <vector>
 #include <string>
 #include <sstream>
@@ -30,6 +31,7 @@
 #include "position.h"
 #include "variant.h"
 
+namespace Stockfish {
 
 enum Notation {
     NOTATION_DEFAULT,
@@ -183,7 +185,7 @@ inline Disambiguation disambiguation_level(const Position& pos, Move m, Notation
 
     while (b)
     {
-        Square s = pop_lsb(&b);
+        Square s = pop_lsb(b);
         if (   pos.pseudo_legal(make_move(s, to))
                && pos.legal(make_move(s, to))
                && !(is_shogi(n) && pos.unpromoted_piece_on(s) != pos.unpromoted_piece_on(from)))
@@ -297,12 +299,15 @@ inline bool has_insufficient_material(Color c, const Position& pos) {
     // Other win rules
     if (   pos.captures_to_hand()
         || pos.count_in_hand(c, ALL_PIECES)
-        || pos.extinction_value() != VALUE_NONE
+        || (pos.extinction_value() != VALUE_NONE && !pos.extinction_pseudo_royal())
         || (pos.capture_the_flag_piece() && pos.count(c, pos.capture_the_flag_piece())))
         return false;
 
     // Restricted pieces
     Bitboard restricted = pos.pieces(~c, KING);
+    // Atomic kings can not help checkmating
+    if (pos.extinction_pseudo_royal() && pos.blast_on_capture() && pos.extinction_piece_types().find(COMMONER) != pos.extinction_piece_types().end())
+        restricted |= pos.pieces(c, COMMONER);
     for (PieceType pt : pos.piece_types())
         if (pt == KING || !(pos.board_bb(c, pt) & pos.board_bb(~c, KING)))
             restricted |= pos.pieces(c, pt);
@@ -320,11 +325,11 @@ inline bool has_insufficient_material(Color c, const Position& pos) {
     for (PieceType pt : { BISHOP, FERS, FERS_ALFIL, ALFIL, ELEPHANT })
         colorbound |= pos.pieces(pt) & ~restricted;
     unbound = pos.pieces() ^ restricted ^ colorbound;
-    if ((colorbound & pos.pieces(c)) && (((DarkSquares & colorbound) && (~DarkSquares & colorbound)) || unbound || pos.stalemate_value() != VALUE_DRAW || pos.check_counting()))
+    if ((colorbound & pos.pieces(c)) && (((DarkSquares & colorbound) && (~DarkSquares & colorbound)) || unbound || pos.stalemate_value() != VALUE_DRAW || pos.check_counting() || pos.makpong()))
         return false;
 
     // Unbound pieces require one helper piece of either color
-    if ((pos.pieces(c) & unbound) && (popcount(pos.pieces() ^ restricted) >= 2 || pos.stalemate_value() != VALUE_DRAW || pos.check_counting()))
+    if ((pos.pieces(c) & unbound) && (popcount(pos.pieces() ^ restricted) >= 2 || pos.stalemate_value() != VALUE_DRAW || pos.check_counting() || pos.makpong()))
         return false;
 
     return true;
@@ -927,4 +932,6 @@ inline FenValidation validate_fen(const std::string& fen, const Variant* v, bool
 }
 } // namespace FEN
 
+} // namespace Stockfish
+
 #endif // #ifndef APIUTIL_H_INCLUDED
