@@ -71,11 +71,15 @@ bitflags! {
         const SSE41     = 1 << 2;
         const AVX2      = 1 << 3;
         const FAST_BMI2 = 1 << 4;
+        const AVX512    = 1 << 5;
+        const VNNI512   = 1 << 6;
 
         const SF_SSE2         = Cpu::SSE2.bits;
         const SF_SSE41_POPCNT = Cpu::SSE41.bits | Cpu::POPCNT.bits;
         const SF_AVX2         = Cpu::SF_SSE41_POPCNT.bits | Cpu::AVX2.bits;
         const SF_BMI2         = Cpu::SF_AVX2.bits | Cpu::FAST_BMI2.bits;
+        const SF_AVX512       = Cpu::SF_BMI2.bits | Cpu::AVX512.bits;
+        const SF_VNNI512      = Cpu::SF_AVX512.bits | Cpu::VNNI512.bits;
     }
 }
 
@@ -111,6 +115,16 @@ impl Cpu {
                 }
             },
         );
+        cpu.set(
+            Cpu::AVX512,
+            is_x86_feature_detected!("avx512f") && is_x86_feature_detected!("avx512bw"),
+        );
+        cpu.set(
+            Cpu::VNNI512,
+            is_x86_feature_detected!("avx512dq")
+                && is_x86_feature_detected!("avx512vl")
+                && is_x86_feature_detected!("avx512vnni"),
+        );
         cpu
     }
 
@@ -127,20 +141,37 @@ const NNUE: Asset = Asset {
     executable: false,
 };
 
-#[cfg(all(unix, target_arch = "x86_64"))]
 const STOCKFISH: &[Asset] = &[
+    // Unix (x86_64)
+    #[cfg(stockfish_x86_64_vnni512)]
+    Asset {
+        name: "stockfish-x86-64-vnni512",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64-vnni512.xz")),
+        needs: Cpu::SF_VNNI512,
+        executable: true,
+    },
+    #[cfg(stockfish_x86_64_avx512)]
+    Asset {
+        name: "stockfish-x86-64-avx512",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64-avx512.xz")),
+        needs: Cpu::SF_AVX512,
+        executable: true,
+    },
+    #[cfg(stockfish_x86_64_bmi2)]
     Asset {
         name: "stockfish-x86-64-bmi2",
         data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64-bmi2.xz")),
         needs: Cpu::SF_BMI2,
         executable: true,
     },
+    #[cfg(stockfish_x86_64_avx2)]
     Asset {
         name: "stockfish-x86-64-avx2",
         data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64-avx2.xz")),
         needs: Cpu::SF_AVX2,
         executable: true,
     },
+    #[cfg(stockfish_x86_64_sse41_popcnt)]
     Asset {
         name: "stockfish-x86-64-sse41-popcnt",
         data: include_bytes!(concat!(
@@ -150,59 +181,51 @@ const STOCKFISH: &[Asset] = &[
         needs: Cpu::SF_SSE41_POPCNT,
         executable: true,
     },
+    #[cfg(stockfish_x86_64)]
     Asset {
         name: "stockfish-x86-64",
         data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64.xz")),
         needs: Cpu::SF_SSE2,
         executable: true,
     },
-];
-
-#[cfg(all(unix, target_arch = "x86_64"))]
-const STOCKFISH_MV: &[Asset] = &[
+    // Unix (aarch64)
+    #[cfg(stockfish_armv8)]
     Asset {
-        name: "fairy-stockfish-x86-64-bmi2",
-        data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-x86-64-bmi2.xz")),
-        needs: Cpu::SF_BMI2,
+        name: "stockfish-armv8",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-armv8.xz")),
+        needs: Cpu::empty(),
         executable: true,
     },
+    // Windows
+    #[cfg(stockfish_x86_64_vnni512_exe)]
     Asset {
-        name: "fairy-stockfish-x86-64-avx2",
-        data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-x86-64-avx2.xz")),
-        needs: Cpu::SF_AVX2,
+        name: "stockfish-x86-64-vnni512.exe",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64-vnni512.exe.xz")),
+        needs: Cpu::SF_VNNI512,
         executable: true,
     },
+    #[cfg(stockfish_x86_64_avx512_exe)]
     Asset {
-        name: "fairy-stockfish-x86-64-sse41-popcnt",
-        data: include_bytes!(concat!(
-            env!("OUT_DIR"),
-            "/fairy-stockfish-x86-64-sse41-popcnt.xz"
-        )),
-        needs: Cpu::SF_SSE41_POPCNT,
+        name: "stockfish-x86-64-avx512.exe",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64-avx512.exe.xz")),
+        needs: Cpu::SF_AVX512,
         executable: true,
     },
-    Asset {
-        name: "fairy-stockfish-x86-64",
-        data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-x86-64.xz")),
-        needs: Cpu::SF_SSE2,
-        executable: true,
-    },
-];
-
-#[cfg(all(windows, target_arch = "x86_64"))]
-const STOCKFISH: &[Asset] = &[
+    #[cfg(stockfish_x86_64_bmi2_exe)]
     Asset {
         name: "stockfish-x86-64-bmi2.exe",
         data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64-bmi2.exe.xz")),
         needs: Cpu::SF_BMI2,
         executable: true,
     },
+    #[cfg(stockfish_x86_64_avx2_exe)]
     Asset {
         name: "stockfish-x86-64-avx2.exe",
         data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64-avx2.exe.xz")),
         needs: Cpu::SF_AVX2,
         executable: true,
     },
+    #[cfg(stockfish_x86_64_sse41_popcnt_exe)]
     Asset {
         name: "stockfish-x86-64-sse41-popcnt.exe",
         data: include_bytes!(concat!(
@@ -212,16 +235,106 @@ const STOCKFISH: &[Asset] = &[
         needs: Cpu::SF_SSE41_POPCNT,
         executable: true,
     },
+    #[cfg(stockfish_x86_64_exe)]
     Asset {
         name: "stockfish-x86-64.exe",
         data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-x86-64.exe.xz")),
         needs: Cpu::SF_SSE2,
         executable: true,
     },
+    // OSX (aarch64)
+    #[cfg(stockfish_apple_silicon)]
+    Asset {
+        name: "stockfish-apple-silicon",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-apple-silicon.xz")),
+        needs: Cpu::empty(),
+        executable: true,
+    },
 ];
 
-#[cfg(all(windows, target_arch = "x86_64"))]
 const STOCKFISH_MV: &[Asset] = &[
+    // Unix (x86_64)
+    #[cfg(fairy_stockfish_x86_64_vnni512)]
+    Asset {
+        name: "fairy-stockfish-x86-64-vnni512",
+        data: include_bytes!(concat!(
+            env!("OUT_DIR"),
+            "/fairy-stockfish-x86-64-vnni512.xz"
+        )),
+        needs: Cpu::SF_VNNI512,
+        executable: true,
+    },
+    #[cfg(fairy_stockfish_x86_64_avx512)]
+    Asset {
+        name: "fairy-stockfish-x86-64-avx512",
+        data: include_bytes!(concat!(
+            env!("OUT_DIR"),
+            "/fairy-stockfish-x86-64-avx512.xz"
+        )),
+        needs: Cpu::SF_AVX512,
+        executable: true,
+    },
+    #[cfg(fairy_stockfish_x86_64_bmi2)]
+    Asset {
+        name: "fairy-stockfish-x86-64-bmi2",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-x86-64-bmi2.xz")),
+        needs: Cpu::SF_BMI2,
+        executable: true,
+    },
+    #[cfg(fairy_stockfish_x86_64_avx2)]
+    Asset {
+        name: "fairy-stockfish-x86-64-avx2",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-x86-64-avx2.xz")),
+        needs: Cpu::SF_AVX2,
+        executable: true,
+    },
+    #[cfg(fairy_stockfish_x86_64_sse41_popcnt)]
+    Asset {
+        name: "fairy-stockfish-x86-64-sse41-popcnt",
+        data: include_bytes!(concat!(
+            env!("OUT_DIR"),
+            "/fairy-stockfish-x86-64-sse41-popcnt.xz"
+        )),
+        needs: Cpu::SF_SSE41_POPCNT,
+        executable: true,
+    },
+    #[cfg(fairy_stockfish_x86_64)]
+    Asset {
+        name: "fairy-stockfish-x86-64",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-x86-64.xz")),
+        needs: Cpu::SF_SSE2,
+        executable: true,
+    },
+    // Unix (aarch64)
+    #[cfg(fairy_stockfish_armv8)]
+    Asset {
+        name: "fairy-stockfish-armv8",
+        data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-armv8.xz")),
+        needs: Cpu::empty(),
+        executable: true,
+    },
+    // Windows
+    #[cfg(fairy_stockfish_x86_64_vnni512_exe)]
+    Asset {
+        name: "fairy-stockfish-x86-64-vnni512.exe",
+        data: include_bytes!(concat!(
+            env!("OUT_DIR"),
+            "/fairy-stockfish-x86-64-vnni512.exe.xz"
+        )),
+        needs: Cpu::SF_VNNI512,
+        executable: true,
+    },
+    #[cfg(fairy_stockfish_x86_64_avx512_exe)]
+    Asset {
+        name: "fairy-stockfish-x86-64-avx512.exe",
+        data: include_bytes!(concat!(
+            env!("OUT_DIR"),
+            "/fairy-stockfish-x86-64-avx512.exe.xz"
+        )),
+        needs: Cpu::SF_AVX512,
+        executable: true,
+    },
+    #[cfg(fairy_stockfish_x86_64_bmi2_exe)]
     Asset {
         name: "fairy-stockfish-x86-64-bmi2.exe",
         data: include_bytes!(concat!(
@@ -231,6 +344,7 @@ const STOCKFISH_MV: &[Asset] = &[
         needs: Cpu::SF_BMI2,
         executable: true,
     },
+    #[cfg(fairy_stockfish_x86_64_avx2_exe)]
     Asset {
         name: "fairy-stockfish-x86-64-avx2.exe",
         data: include_bytes!(concat!(
@@ -240,6 +354,7 @@ const STOCKFISH_MV: &[Asset] = &[
         needs: Cpu::SF_AVX2,
         executable: true,
     },
+    #[cfg(fairy_stockfish_x86_64_sse41_popcnt_exe)]
     Asset {
         name: "fairy-stockfish-x86-64-sse41-popcnt.exe",
         data: include_bytes!(concat!(
@@ -249,49 +364,26 @@ const STOCKFISH_MV: &[Asset] = &[
         needs: Cpu::SF_SSE41_POPCNT,
         executable: true,
     },
+    #[cfg(fairy_stockfish_x86_64_exe)]
     Asset {
         name: "fairy-stockfish-x86-64.exe",
         data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-x86-64.exe.xz")),
         needs: Cpu::SF_SSE2,
         executable: true,
     },
+    // OSX (aarch64)
+    #[cfg(fairy_stockfish_apple_silicon)]
+    Asset {
+        name: "fairy-stockfish-apple-silicon",
+        data: include_bytes!(concat!(
+            env!("OUT_DIR"),
+            "/fairy-stockfish-apple-silicon.xz"
+        )),
+        needs: Cpu::empty(),
+        executable: true,
+    },
 ];
 
-#[cfg(all(target_os = "linux", target_arch = "aarch64"))]
-const STOCKFISH: &[Asset] = &[Asset {
-    name: "stockfish-armv8",
-    data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-armv8.xz")),
-    needs: Cpu::empty(),
-    executable: true,
-}];
-
-#[cfg(all(target_os = "linux", target_arch = "aarch64"))]
-const STOCKFISH_MV: &[Asset] = &[Asset {
-    name: "fairy-stockfish-armv8",
-    data: include_bytes!(concat!(env!("OUT_DIR"), "/fairy-stockfish-armv8.xz")),
-    needs: Cpu::empty(),
-    executable: true,
-}];
-
-#[cfg(all(target_os = "macos", target_arch = "aarch64"))]
-const STOCKFISH: &[Asset] = &[Asset {
-    name: "stockfish-apple-silicon",
-    data: include_bytes!(concat!(env!("OUT_DIR"), "/stockfish-apple-silicon.xz")),
-    needs: Cpu::empty(),
-    executable: true,
-}];
-
-#[cfg(all(target_os = "macos", target_arch = "aarch64"))]
-const STOCKFISH_MV: &[Asset] = &[Asset {
-    name: "fairy-stockfish-apple-silicon",
-    data: include_bytes!(concat!(
-        env!("OUT_DIR"),
-        "/fairy-stockfish-apple-silicon.xz"
-    )),
-    needs: Cpu::empty(),
-    executable: true,
-}];
-
 #[derive(Debug, Copy, Clone, PartialEq, Eq)]
 pub enum EngineFlavor {
     Official,
